@@ -41,13 +41,13 @@ class LibArchiveInterface: public ReadWriteArchiveInterface
     Q_OBJECT
 
 public:
-    explicit LibArchiveInterface(QObject *parent, const QVariantList & args);
+    explicit LibArchiveInterface(QObject *parent, const QVariantList& args);
     ~LibArchiveInterface();
 
     bool list();
-    bool copyFiles(const QList<QVariant> & files, const QString & destinationDirectory, ExtractionOptions options);
-    bool addFiles(const QStringList & files, const CompressionOptions& options);
-    bool deleteFiles(const QList<QVariant> & files);
+    bool copyFiles(const QVariantList& files, const QString& destinationDirectory, ExtractionOptions options);
+    bool addFiles(const QStringList& files, const CompressionOptions& options);
+    bool deleteFiles(const QVariantList& files);
 
 private:
     void emitEntryFromArchiveEntry(struct archive_entry *entry);
@@ -67,6 +67,7 @@ private:
     qlonglong m_extractedFilesSize;
     QDir m_workDir;
     QStringList m_writtenFiles;
+    ArchiveRead m_archiveReadDisk;
 };
 
 #endif // LIBARCHIVEHANDLER_H
