@@ -529,7 +529,7 @@ void KgpgEditor::slotFilePreDec()
 
         KgpgLibrary *lib = new KgpgLibrary(this);
 	connect(lib, SIGNAL(decryptionOver(KUrl)), SLOT(slotLibraryDone()));
-        lib->slotFileDec(url, KUrl(newname), m_customdecrypt);
+        lib->slotFileDec(url, KUrl(newname));
     }
     else
         openEncryptedDocumentFile(url);
