@@ -53,8 +53,6 @@ void KGpgExternalActions::encryptDroppedFile()
 {
 	QStringList opts;
 	KgpgLibrary *lib = new KgpgLibrary(0);
-	if (KGpgSettings::pgpExtension())
-		lib->setFileExtension(QLatin1String( ".pgp" ));
 	connect(lib, SIGNAL(systemMessage(QString)), SLOT(busyMessage(QString)));
 
 	if (KGpgSettings::encryptFilesTo()) {
@@ -346,12 +344,9 @@ void KGpgExternalActions::decryptFile(KgpgLibrary *lib)
 		delete over;
 	}
 
-	QStringList custdecr;
-	if (!KGpgSettings::customDecrypt().isEmpty())
-		custdecr.append(KGpgSettings::customDecrypt());
 	connect(lib, SIGNAL(systemMessage(QString)), SLOT(busyMessage(QString)));
 	connect(lib, SIGNAL(decryptionOver(KUrl)), SLOT(decryptNextFile(KUrl)));
-	lib->slotFileDec(droppedUrls.first(), swapname, custdecr);
+	lib->slotFileDec(droppedUrls.first(), swapname);
 }
 
 void KGpgExternalActions::decryptNextFile(const KUrl &failed, KgpgLibrary *lib)
