@@ -40,21 +40,14 @@ public:
      */
     explicit KgpgLibrary(QWidget *parent = 0);
 
-    /**
-     * set the extension used for the encrypted file (including the '.')
-     */
-    void setFileExtension(const QString &extension);
-
 signals:
     void encryptionOver();
     void decryptionOver(KUrl);
-    void importOver(KgpgLibrary *, QStringList);
     void systemMessage(QString message);
-    void photoAdded();
 
 public slots:
     void slotFileEnc(const KUrl::List &urls, const QStringList &opts, KGpgItemModel *model, const KShortcut &goDefaultKey, const QString &defaultKey = QString());
-    void slotFileDec(const KUrl &srcUrl, const KUrl &destUrl, const QStringList &customDecryptOption = QStringList());
+    void slotFileDec(const KUrl &srcUrl, const KUrl &destUrl);
 
 private slots:
     void processEnc(const KUrl &);
@@ -66,7 +59,7 @@ private:
     void startEncode(const QStringList &encryptkeys, const QStringList &encryptoptions, const bool symetric);
     void fastEncode(const KUrl &filetocrypt, const QStringList &encryptkeys, const QStringList &encryptoptions, const bool symetric);
     QWidget *m_panel;
-    QString m_extension;
+    const QString m_extension;
     QStringList m_encryptkeys;
     QStringList m_encryptoptions;
 
