@@ -19,7 +19,7 @@ KGpgSignKey::KGpgSignKey(QObject *parent, const QString &signer, KGpgKeyNode *ke
 	: KGpgEditKeyTransaction(parent, key->getId(), QString(), false, false),
 	KGpgSignTransactionHelper(signer, !local, checking)
 {
-	insertArgument(1, "-u");
+	insertArgument(1, QLatin1String( "-u" ));
 	insertArgument(2, signer);
 	m_signerPos = 2;
 	addArgumentRef(&m_signerPos);
@@ -36,11 +36,6 @@ KGpgSignKey::~KGpgSignKey()
 bool
 KGpgSignKey::nextLine(const QString &line)
 {
-	if (line.startsWith(QLatin1String("[GNUPG:]")) && line.contains("sign_all.okay")) {
-		write("YES");
-		return false;
-	}
-
 	switch (KGpgSignTransactionHelper::nextLine(line)) {
 	case KGpgSignTransactionHelper::handledFalse:
 		return false;
@@ -57,6 +52,9 @@ KGpgSignKey::nextLine(const QString &line)
 KGpgTransaction::ts_boolanswer
 KGpgSignKey::boolQuestion(const QString& line)
 {
+	if (line.contains(QLatin1String("sign_all.okay")))
+		return BA_YES;
+
 	ts_boolanswer ret = KGpgSignTransactionHelper::boolQuestion(line);
 
 	if (ret == BA_UNKNOWN)
