@@ -41,7 +41,7 @@ class MyApp : public KUniqueApplication {
 };
 
 int main(int argc, char **argv) {
-	KAboutData about("kwalletmanager", 0, ki18n("KDE Wallet Manager"), "1.7",
+	KAboutData about("kwalletmanager", 0, ki18n("KDE Wallet Manager"), "1.8",
 		ki18n("KDE Wallet Management Tool"),
 		KAboutData::License_GPL,
 		ki18n("(c) 2003,2004 George Staikos"), KLocalizedString(),
@@ -68,7 +68,7 @@ int main(int argc, char **argv) {
 	KWalletManager wm;
 	wm.setCaption(i18n("KDE Wallet Manager"));
 
-	KGlobal::dirs()->addResourceType("kwallet", QLatin1String( "share/apps/kwallet" ));
+	KGlobal::dirs()->addResourceType("kwallet", 0, QLatin1String( "share/apps/kwallet" ));
 
 	KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
